@@ -16,7 +16,7 @@ class DatasetManager:
         self.container = container   
     
     @staticmethod
-    def loadDatasetFromFiles(t1_file, t2_file, m0_file,mprage_file, tse_file, 
+    def loadSetFromFiles(t1_file, t2_file, m0_file,mprage_file=None, tse_file=None, 
                              registered_mprage_file=None, registered_tse_file=None):
         T1_img = nib.load(t1_file)
         T1 = T1_img.get_fdata()
@@ -24,11 +24,17 @@ class DatasetManager:
         T2 = T2_img.get_fdata()
         M0_img = nib.load(m0_file)
         M0 = M0_img.get_fdata()
-        MPRAGE_img = nib.load(mprage_file)
-        MPRAGE = MPRAGE_img.get_fdata()
-        TSE_img = nib.load(tse_file)
-        TSE = TSE_img.get_fdata()
-        output = (T1,T2,M0,MPRAGE,TSE)
+        output = (T1,T2,M0)
+        MPRAGE = None
+        if(mprage_file is not None):
+            MPRAGE_img = nib.load(mprage_file)
+            MPRAGE = MPRAGE_img.get_fdata()
+            output = output + MPRAGE
+        TSE = None
+        if(tse_file is not None):
+            TSE_img = nib.load(tse_file)
+            TSE = TSE_img.get_fdata()
+            output = output + TSE
         registered_MPRAGE = None
         if(registered_mprage_file is not None):
             registered_MPRAGE_img = nib.load(registered_mprage_file)
@@ -41,13 +47,12 @@ class DatasetManager:
             output = output + registered_TSE
         return output
     
-
-    def saveToDataset(self, subject, scanner, set, label, nifti):
+    def saveToSet(self, subject, scanner, set, label, nifti):
         path_base = self.localDataRootDir+"/"+subject+"/"+scanner+"/"+set
         filename = path_base + "_" + label + ".nii"
         nib.save(nifti,filename)
         
-    def saveToDataset(self, subject, scanner, set, label, numpyData, niftiTransformSourceLabel):
+    def saveToSet(self, subject, scanner, set, label, numpyData, niftiTransformSourceLabel):
         path_base = self.localDataRootDir+"/"+subject+"/"+scanner+"/"+set
         filename = path_base + "_" + label + ".nii"
         niftiTransformSourceFilename = path_base + "_" + niftiTransformSourceLabel + ".nii"
@@ -55,8 +60,25 @@ class DatasetManager:
         newNifti = nib.Nifti1Image(numpyData,niftiTransformSource.affine)
         nib.save(newNifti,filename)
 
-    def loadDataset(self, subject, scanner, set, includeRegisteredMPRAGE=False, includeRegisteredTSE=False):
+    def loadMRFSeries(self, subject, scanner, set):
         path_base = self.localDataRootDir+"/"+subject+"/"+scanner+"/"+set
+        return self.loadDatasetFromFiles(path_base+"_t1.nii", path_base+"_t2.nii", path_base+"_m0.nii")
+
+    def loadSingleSeries(self, subject, scanner, set, series, extension=".nii"):
+        path_base = self.localDataRootDir+"/"+subject+"/"+scanner+"/"+set
+        series_file = path_base+"_"+series+extension
+        series_img = nib.load(series_file)
+        series = series_img.get_fdata()
+        return series
+
+    def loadSet(self, subject, scanner, set, includeMPRAGE=False, includeTSE=False, includeRegisteredMPRAGE=False, includeRegisteredTSE=False):
+        path_base = self.localDataRootDir+"/"+subject+"/"+scanner+"/"+set
+        mprage_file = None
+        if(includeMPRAGE):
+            mprage_file = path_base+"_mprage.nii"
+        tse_file = None
+        if(includeTSE):
+            tse_file = path_base+"_tse.nii"
         registered_mprage_file = None
         if(includeRegisteredMPRAGE):
             registered_mprage_file = path_base+"_mprage_registered.nii"
@@ -64,9 +86,9 @@ class DatasetManager:
         if(includeRegisteredTSE):
             registered_tse_file = path_base+"_tse_registered.nii"
         return self.loadDatasetFromFiles(path_base+"_t1.nii", path_base+"_t2.nii", path_base+"_m0.nii",
-                                         path_base+"_mprage.nii", path_base+"_tse.nii", registered_mprage_file, registered_tse_file)
+                                         mprage_file, tse_file, registered_mprage_file, registered_tse_file)
 
-    def fetchDatasetFromAzure(self, subject, scanner, set):
+    def fetchSetFromAzure(self, subject, scanner, set, includeMPRAGE=False, includeTSE=False):
         if(self.connectionString == None or self.container == None):
             print("Dataset Manager Azure connection string or container not set.")
             return None
@@ -88,13 +110,15 @@ class DatasetManager:
                 download_file.write(container_client.download_blob(uri_base+"_b1.nii").readall())
             with open(path_base+"_m0.nii", "wb") as download_file:
                 download_file.write(container_client.download_blob(uri_base+"_m0.nii").readall())
-            with open(path_base+"_tse.nii", "wb") as download_file:
-                download_file.write(container_client.download_blob(uri_base+"_tse.nii").readall())
-            with open(path_base+"_mprage.nii", "wb") as download_file:
-                download_file.write(container_client.download_blob(uri_base+"_mprage.nii").readall())
-            return self.loadDataset(subject, scanner, set)
+            if(includeMPRAGE):
+                with open(path_base+"_tse.nii", "wb") as download_file:
+                    download_file.write(container_client.download_blob(uri_base+"_tse.nii").readall())
+            if(includeTSE):
+                with open(path_base+"_mprage.nii", "wb") as download_file:
+                    download_file.write(container_client.download_blob(uri_base+"_mprage.nii").readall())
+            return self.loadDataset(subject, scanner, set, includeMPRAGE=includeMPRAGE, includeTSE=includeTSE)
 
-    def pushDatasetToAzure(self, containerName, subject, scanner, set, regex):
+    def pushSetToAzure(self, containerName, subject, scanner, set, regex):
         if(self.connectionString == None):
             print("Dataset Manager Azure connection string not set.")
             return None
